@@ -64,8 +64,9 @@ def view_handler(view):
     def wrapper(request, *args, **kwargs):
         """The decorated implementation.
         """
-        if request.META.get('CONTENT_TYPE') == 'application/json' and \
-                request.META.get('CONTENT_LENGTH'):
+        meta = request.META
+        if meta.get('CONTENT_TYPE', '').startswith('application/json') and \
+                meta.get('CONTENT_LENGTH'):
             request.POST = loads(request.raw_post_data)
         response = {'_meta': dict(status=200, message='OK')}
         try:
